@@ -29,7 +29,7 @@ namespace gpgQCAPlugin
 
 Q_GLOBAL_STATIC(QMutex, ksl_mutex)
 
-static MyKeyStoreList *keyStoreList = 0;
+static MyKeyStoreList *keyStoreList = nullptr;
 MyKeyStoreList::MyKeyStoreList(Provider *p)
 	: KeyStoreListContext(p)
 	, initialized(false)
@@ -41,24 +41,24 @@ MyKeyStoreList::MyKeyStoreList(Provider *p)
 	QMutexLocker locker(ksl_mutex());
 	keyStoreList = this;
 
-	connect(&gpg, SIGNAL(finished()), SLOT(gpg_finished()));
-	connect(&ringWatch, SIGNAL(changed(const QString &)), SLOT(ring_changed(const QString &)));
+	connect(&gpg, &GpgOp::finished, this, &MyKeyStoreList::gpg_finished);
+	connect(&ringWatch, &RingWatch::changed, this, &MyKeyStoreList::ring_changed);
 }
 
 MyKeyStoreList::~MyKeyStoreList()
 {
 	QMutexLocker locker(ksl_mutex());
-	keyStoreList = 0;
+	keyStoreList = nullptr;
 }
 
 Provider::Context *MyKeyStoreList::clone() const
 {
-	return 0;
+	return nullptr;
 }
 
 QString MyKeyStoreList::name(int) const
 {
-	return "GnuPG Keyring";
+	return QStringLiteral("GnuPG Keyring");
 }
 
 KeyStore::Type MyKeyStoreList::type(int) const
@@ -68,7 +68,7 @@ KeyStore::Type MyKeyStoreList::type(int) const
 
 QString MyKeyStoreList::storeId(int) const
 {
-	return "qca-gnupg";
+	return QStringLiteral("qca-gnupg");
 }
 
 QList<int> MyKeyStoreList::keyStores()
@@ -139,7 +139,7 @@ KeyStoreEntryContext *MyKeyStoreList::entry(int, const QString &entryId)
 
 	PGPKey pub = getPubKey(entryId);
 	if(pub.isNull())
-		return 0;
+		return nullptr;
 
 	// optional
 	PGPKey sec = getSecKey(entryId, static_cast<MyPGPKeyContext *>(pub.context())->_props.userIds);
@@ -156,17 +156,17 @@ KeyStoreEntryContext *MyKeyStoreList::entryPassive(const QString &serialized)
 
 	QStringList parts = serialized.split(':');
 	if(parts.count() < 2)
-		return 0;
-	if(unescape_string(parts[0]) != "qca-gnupg-1")
-		return 0;
+		return nullptr;
+	if(unescape_string(parts[0]) != QLatin1String("qca-gnupg-1"))
+		return nullptr;
 
 	QString entryId = unescape_string(parts[1]);
 	if(entryId.isEmpty())
-		return 0;
+		return nullptr;
 
 	PGPKey pub = getPubKey(entryId);
 	if(pub.isNull())
-		return 0;
+		return nullptr;
 
 	// optional
 	PGPKey sec = getSecKey(entryId, static_cast<MyPGPKeyContext *>(pub.context())->_props.userIds);
@@ -453,7 +453,7 @@ void MyKeyStoreList::gpg_finished()
 
 void MyKeyStoreList::ring_changed(const QString &filePath)
 {
-	ext_keyStoreLog(QString("ring_changed: [%1]\n").arg(filePath));
+	ext_keyStoreLog(QStringLiteral("ring_changed: [%1]\n").arg(filePath));
 
 	if(filePath == secring)
 		sec_changed();
