@@ -26,9 +26,9 @@ ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 // LICENSEHEADER_END
 namespace QCA { // WRAPNS_LINE
 /*************************************************
- * Basic Allocators Header File                   *
- * (C) 1999-2007 The Botan Project                *
- *************************************************/
+* Basic Allocators Header File                   *
+* (C) 1999-2007 The Botan Project                *
+*************************************************/
 
 #ifndef BOTAN_BASIC_ALLOC_H__
 #define BOTAN_BASIC_ALLOC_H__
@@ -40,44 +40,30 @@ namespace QCA { // WRAPNS_LINE
 namespace Botan {
 
 /*************************************************
- * Malloc Allocator                              *
- *************************************************/
+* Malloc Allocator                              *
+*************************************************/
 class Malloc_Allocator : public Pooling_Allocator
-{
-public:
-    Malloc_Allocator()
-        : Pooling_Allocator(64 * 1024, false)
-    {
-    }
-    std::string type() const override
-    {
-        return "malloc";
-    }
-
-private:
-    void *alloc_block(u32bit) override;
-    void  dealloc_block(void *, u32bit) override;
-};
+   {
+   public:
+      Malloc_Allocator() : Pooling_Allocator(64*1024, false) {}
+      std::string type() const override { return "malloc"; }
+   private:
+      void* alloc_block(u32bit) override;
+      void dealloc_block(void*, u32bit) override;
+   };
 
 /*************************************************
- * Locking Allocator                              *
- *************************************************/
+* Locking Allocator                              *
+*************************************************/
 class Locking_Allocator : public Pooling_Allocator
-{
-public:
-    Locking_Allocator()
-        : Pooling_Allocator(64 * 1024, true)
-    {
-    }
-    std::string type() const override
-    {
-        return "locking";
-    }
-
-private:
-    void *alloc_block(u32bit) override;
-    void  dealloc_block(void *, u32bit) override;
-};
+   {
+   public:
+      Locking_Allocator() : Pooling_Allocator(64*1024, true) {}
+      std::string type() const override { return "locking"; }
+   private:
+      void* alloc_block(u32bit) override;
+      void dealloc_block(void*, u32bit) override;
+   };
 
 }
 
