@@ -25,8 +25,8 @@
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
-#include <QTest>
 #include <QtCrypto>
+#include <QtTest/QtTest>
 
 #ifdef QT_STATICPLUGIN
 #include "import_plugins.h"
@@ -43,9 +43,8 @@ private Q_SLOTS:
     void test1();
     void test2_data();
     void test2();
-
 private:
-    QCA::Initializer *m_init;
+    QCA::Initializer* m_init;
 };
 
 void Base64UnitTest::initTestCase()
@@ -66,38 +65,39 @@ void Base64UnitTest::test1_data()
     // these are from the Botan test suite. Note that these are hex encoded!
     QTest::newRow("31") << QStringLiteral("31") << QStringLiteral("4d513d3d");
     QTest::newRow("235c91") << QStringLiteral("235c91") << QStringLiteral("49317952");
-    QTest::newRow("414") << QStringLiteral("4142634452313236") << QStringLiteral("51554a6a524649784d6a593d");
+    QTest::newRow("414") << QStringLiteral("4142634452313236")
+			 << QStringLiteral("51554a6a524649784d6a593d");
     QTest::newRow("241") << QStringLiteral("241bb300a3989a620659")
-                         << QStringLiteral("4a42757a414b4f596d6d494757513d3d");
+			 << QStringLiteral("4a42757a414b4f596d6d494757513d3d");
     QTest::newRow("313") << QStringLiteral("31323537374343666671333435337836")
-                         << QStringLiteral("4d5449314e7a644451325a6d63544d304e544e344e673d3d");
+			 << QStringLiteral("4d5449314e7a644451325a6d63544d304e544e344e673d3d");
     QTest::newRow("60e") << QStringLiteral("60e8e5ebb1a5eac95a01ec7f8796b2dce471")
-                         << QStringLiteral("594f6a6c3637476c36736c614165782f68356179334f5278");
+			 << QStringLiteral("594f6a6c3637476c36736c614165782f68356179334f5278");
     QTest::newRow("3134") << QStringLiteral("31346d354f33313333372c31274d754e7354307050346231333a29")
-                          << QStringLiteral("4d5452744e55387a4d544d7a4e7977784a303131546e4e554d4842514e4749784d7a6f70");
+			  << QStringLiteral("4d5452744e55387a4d544d7a4e7977784a303131546e4e554d4842514e4749784d7a6f70");
 }
 
+
 void Base64UnitTest::test2_data()
 {
     QTest::addColumn<QString>("raw");
     QTest::addColumn<QString>("encoded");
 
     // these are from Python 2.3's tests for base64
-    QTest::newRow("www.python.org") << QStringLiteral("www.python.org") << QStringLiteral("d3d3LnB5dGhvbi5vcmc=");
+    QTest::newRow("www.python.org") << QStringLiteral("www.python.org")
+				    << QStringLiteral("d3d3LnB5dGhvbi5vcmc=");
     QTest::newRow("a") << QStringLiteral("a") << QStringLiteral("YQ==");
     QTest::newRow("ab") << QStringLiteral("ab") << QStringLiteral("YWI=");
     QTest::newRow("abc") << QStringLiteral("abc") << QStringLiteral("YWJj");
     QTest::newRow("empty") << QString(QLatin1String("")) << QString(QLatin1String(""));
-    QTest::newRow("a-Z") << QStringLiteral(
-                                "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#0^&*();:<>,. []{}")
-                         << QStringLiteral(
-                                "YWJjZGVmZ2hpamtsbW5vcHFyc3R1dnd4eXpBQkNERUZHSElKS0xNTk9QUVJTVFVWV1hZWjAxMjM0NTY3ODkhQC"
-                                "MwXiYqKCk7Ojw+LC4gW117fQ==");
+    QTest::newRow("a-Z") << QStringLiteral("abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789!@#0^&*();:<>,. []{}")
+			 << QStringLiteral("YWJjZGVmZ2hpamtsbW5vcHFyc3R1dnd4eXpBQkNERUZHSElKS0xNTk9QUVJTVFVWV1hZWjAxMjM0NTY3ODkhQCMwXiYqKCk7Ojw+LC4gW117fQ==");
 
     // these are generated by Python 2.3. I removed the trailing newline
     QTest::newRow("31") << QStringLiteral("31") << QStringLiteral("MzE=");
     QTest::newRow("QCA_2.0") << QStringLiteral("QCA_2.0") << QStringLiteral("UUNBXzIuMA==");
-    QTest::newRow("j-0") << QStringLiteral("jh/*-*/*-/4983589230") << QStringLiteral("amgvKi0qLyotLzQ5ODM1ODkyMzA=");
+    QTest::newRow("j-0") << QStringLiteral("jh/*-*/*-/4983589230")
+			 << QStringLiteral("amgvKi0qLyotLzQ5ODM1ODkyMzA=");
 }
 
 void Base64UnitTest::test1()
@@ -118,11 +118,11 @@ void Base64UnitTest::test2()
     QFETCH(QString, raw);
     QFETCH(QString, encoded);
 
-    QCOMPARE(base64Object.encodeString(raw), encoded);
-    QCOMPARE(base64Object.decodeString(encoded), raw);
+    QCOMPARE( base64Object.encodeString(raw), encoded );
+    QCOMPARE( base64Object.decodeString(encoded), raw );
 
-    QCOMPARE(QCA::arrayToBase64(raw.toUtf8()), encoded);
-    QCOMPARE(QLatin1String(QCA::base64ToArray(encoded)), raw);
+    QCOMPARE( QCA::arrayToBase64(raw.toUtf8()), encoded );
+    QCOMPARE( QLatin1String(QCA::base64ToArray(encoded)), raw );
 }
 
 QTEST_MAIN(Base64UnitTest)
